'use client';
var jsxRuntime = require('react/jsx-runtime');
var reactUtils = require('@gateweb/react-utils');
var material = require('@mui/material');
var React = require('react');

const TextFieldStyled = material.styled(material.TextField)`
  input {
    text-align: center;
  }
`;
const OTPField = /*#__PURE__*/ React.forwardRef(({ value: outerValue, defaultValue = '', length = 4, autoFocus = false, className, TextFieldsProps, onChange, validateChar, onBlur, ...restBoxProps }, boxRef)=>{
    const [value, setValue] = reactUtils.useValue({
        value: outerValue,
        defaultValue
    });
    const valueSplitted = React.useMemo(()=>Array.from({
            length
        }, (_, index)=>({
                character: value?.[index] || '',
                inputRef: /*#__PURE__*/ React.createRef()
            })), [
        value,
        length
    ]);
    const focusInput = (inputIndex)=>{
        valueSplitted[inputIndex]?.inputRef.current?.focus();
    };
    const selectInput = (inputIndex)=>{
        valueSplitted[inputIndex]?.inputRef.current?.select();
    };
    const handleChange = (newValue)=>{
        if (onChange) {
            onChange(newValue);
        } else {
            setValue(newValue);
        }
    };
    const handleInputChange = (event)=>{
        const currentInputIndex = valueSplitted.findIndex(({ inputRef })=>inputRef.current === event.target);
        const changeChar = event.target.value[0];
        if (validateChar && typeof validateChar === 'function' && !validateChar(changeChar, currentInputIndex)) {
            return;
        }
        const newValue = valueSplitted.map(({ character }, index)=>index === currentInputIndex ? changeChar : character).join('');
        handleChange(newValue);
        if (changeChar) {
            if (newValue.length - 1 < currentInputIndex) {
                selectInput(newValue.length);
            } else {
                if (currentInputIndex + 1 === length) return;
                if (valueSplitted[currentInputIndex + 1].character) {
                    selectInput(currentInputIndex + 1);
                } else {
                    focusInput(currentInputIndex + 1);
                }
            }
            return;
        }
        if (newValue.length <= currentInputIndex) {
            selectInput(currentInputIndex - 1);
        }
    };
    const handleInputKeyDown = (event)=>{
        const currentInputIndex = valueSplitted.findIndex(({ inputRef })=>inputRef.current === event.target);
        const inputElement = event.target;
        switch(event.key){
            case 'Backspace':
                if (!inputElement.value) {
                    event.preventDefault();
                    selectInput(currentInputIndex - 1);
                    break;
                }
                if (inputElement.selectionStart === 0 && inputElement.selectionEnd === 0) {
                    event.preventDefault();
                    const newValue = valueSplitted.map(({ character }, index)=>index === currentInputIndex ? '' : character).join('');
                    handleChange(newValue);
                    if (newValue.length <= currentInputIndex) {
                        selectInput(currentInputIndex - 1);
                    }
                }
                break;
            case 'ArrowLeft':
                event.preventDefault();
                selectInput(currentInputIndex - 1);
                break;
            case 'ArrowRight':
                event.preventDefault();
                selectInput(currentInputIndex + 1);
                break;
            case 'Home':
                event.preventDefault();
                selectInput(0);
                break;
            case 'End':
                event.preventDefault();
                selectInput(valueSplitted.length - 1);
                break;
            default:
                if (inputElement.value === event.key) {
                    event.preventDefault();
                    if (currentInputIndex + 1 === length) break;
                    if (valueSplitted[currentInputIndex + 1].character) {
                        selectInput(currentInputIndex + 1);
                    } else {
                        focusInput(currentInputIndex + 1);
                    }
                    break;
                }
                break;
        }
    };
    const handleInputPaste = (event)=>{
        const content = event.clipboardData.getData('text/plain');
        const inputElement = event.target;
        const currentInputIndex = valueSplitted.findIndex(({ character, inputRef })=>character === '' || inputRef.current === inputElement);
        const newValue = valueSplitted.reduce((acc, cur, index)=>{
            if (index < currentInputIndex) {
                return {
                    ...acc,
                    characters: [
                        ...acc.characters,
                        cur.character
                    ]
                };
            }
            const [first, ...rest] = acc.restArrayMerged;
            return {
                restArrayMerged: rest,
                characters: [
                    ...acc.characters,
                    first ?? ''
                ]
            };
        }, {
            restArrayMerged: content.split(''),
            characters: []
        }).characters.filter((char, index)=>{
            if (validateChar && typeof validateChar === 'function' && !validateChar(char, index)) {
                return false;
            }
            return true;
        }).join('');
        handleChange(newValue);
        selectInput(Math.min(newValue.length, length - 1));
    };
    return /*#__PURE__*/ jsxRuntime.jsx(material.Box, {
        display: "flex",
        gap: 2,
        alignItems: "center",
        ref: boxRef,
        className: `OTPFiled-Box ${className || ''}`,
        ...restBoxProps,
        children: valueSplitted.map(({ character, inputRef }, index)=>{
            const { onPaste, onFocus, onKeyDown, className: TextFieldClassName = '', onBlur: TextFieldOnBlur, inputRef: TextFieldInputRef, ...restTextFieldsProps } = typeof TextFieldsProps === 'function' ? TextFieldsProps(index) || {} : TextFieldsProps || {};
            return /*#__PURE__*/ jsxRuntime.jsx(TextFieldStyled, {
                autoFocus: autoFocus ? index === 0 : false,
                autoComplete: "one-time-code",
                value: character,
                inputRef: reactUtils.mergeRefs([
                    inputRef,
                    TextFieldInputRef
                ]),
                className: `OTPFiled-TextField OTPFiled-TextField-${index + 1} ${TextFieldClassName}`,
                onChange: handleInputChange,
                onKeyDown: handleInputKeyDown,
                onPaste: (event)=>{
                    event.preventDefault();
                    handleInputPaste(event);
                    onPaste?.(event);
                },
                onFocus: (event)=>{
                    event.preventDefault();
                    event.target.select();
                    onFocus?.(event);
                },
                onBlur: onBlur,
                ...restTextFieldsProps
            }, index);
        })
    });
});

exports.OTPField = OTPField;
