'use client';
var jsxRuntime = require('react/jsx-runtime');
var material = require('@mui/material');
var Box = require('@mui/material/Box');
var React = require('react');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var Box__default = /*#__PURE__*/_interopDefault(Box);

const SIDEBAR_WIDTH = 260;
const SIDEBAR_WIDTH_MOBILE = 300;
const SIDEBAR_WIDTH_ICON = 50;
const SidebarContext = /*#__PURE__*/ React.createContext(null);
const useSidebar = ()=>{
    const context = React.useContext(SidebarContext);
    if (!context) {
        throw new Error('useSidebar must be used within a SidebarProvider.');
    }
    return context;
};
const SidebarProvider = /*#__PURE__*/ React.forwardRef(({ widthConfig: widthConfigProps, defaultOpen = true, open: outerOpen, onOpenChange: setOuterOpen, children, sx, ...props }, ref)=>{
    const theme = material.useTheme();
    const isMobile = material.useMediaQuery(theme.breakpoints.between('xs', 'sm'));
    const [openMobile, setOpenMobile] = React.useState(false);
    // This is the internal state of the sidebar.
    // We use outerOpen and setOuterOpen for control from outside the component.
    const [innerOpen, setInnerOpen] = React.useState(defaultOpen);
    const open = outerOpen ?? innerOpen;
    const setOpen = React.useCallback((value)=>{
        const openState = typeof value === 'function' ? value(open) : value;
        if (setOuterOpen) {
            setOuterOpen(openState);
        } else {
            setInnerOpen(openState);
        }
    }, [
        setOuterOpen,
        open
    ]);
    // Helper to toggle the sidebar.
    const toggleSidebar = React.useCallback(()=>isMobile ? setOpenMobile((preOpen)=>!preOpen) : setOpen((preOpen)=>!preOpen), [
        isMobile,
        setOpen,
        setOpenMobile
    ]);
    const width = React.useMemo(()=>{
        const widthConfig = {
            ...{
                width: SIDEBAR_WIDTH,
                widthIcon: SIDEBAR_WIDTH_ICON,
                widthMobile: SIDEBAR_WIDTH_MOBILE
            },
            ...widthConfigProps
        };
        if (isMobile) return widthConfig.widthMobile;
        return open ? widthConfig.width : widthConfig.widthIcon;
    }, [
        isMobile,
        open,
        widthConfigProps
    ]);
    const contextValue = React.useMemo(()=>({
            open,
            setOpen,
            isMobile,
            openMobile,
            setOpenMobile,
            toggleSidebar,
            width
        }), [
        open,
        setOpen,
        isMobile,
        openMobile,
        setOpenMobile,
        toggleSidebar,
        width
    ]);
    return /*#__PURE__*/ jsxRuntime.jsx(SidebarContext.Provider, {
        value: contextValue,
        children: /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
            ref: ref,
            sx: {
                display: 'flex',
                minHeight: '100svh',
                ...sx
            },
            ...props,
            children: children
        })
    });
});
SidebarProvider.displayName = 'SidebarProvider';

exports.SidebarProvider = SidebarProvider;
exports.useSidebar = useSidebar;
