'use client';
import { jsx, jsxs } from 'react/jsx-runtime';
import { Box, Breadcrumbs as Breadcrumbs$1 } from '@mui/material';
import * as React from 'react';
import { forwardRef } from 'react';
import { B as BreadcrumbsProvider } from './BreadCrumbContext-12s-DPRdxc6-.mjs';

/**
 * `Breadcrumb` 是一個導航元件，用於顯示當前系統層級結構中的路徑位置。
 *
 * 參考 [Material-UI Breadcrumbs](https://mui.com/material-ui/react-breadcrumbs/)
 *
 * @example
 *
 * ```tsx
 * <Breadcrumbs>
 *  <BreadcrumbItem>Home</BreadcrumbItem>
 *  <BreadcrumbItem>Components</BreadcrumbItem>
 *  <BreadcrumbItem isLast>Button</BreadcrumbItem>
 * </Breadcrumbs>
 *
 * // 也可以自訂子節點元件
 * <Breadcrumbs>
 *  <span>Home</span>
 *  <span>Components</span>
 *  <span>Button</span>
 * </Breadcrumbs>
 * ```
 */ const Breadcrumbs = /*#__PURE__*/ forwardRef(({ children, extractCurrent, currentPosition = 'top', containerProps, ...props }, ref)=>{
    if (extractCurrent) {
        const childrenArray = React.Children.toArray(children);
        const lastChild = childrenArray[childrenArray.length - 1];
        const previousChildren = childrenArray.slice(0, -1);
        return /*#__PURE__*/ jsx(BreadcrumbsProvider, {
            extractCurrent,
            currentPosition,
            children: /*#__PURE__*/ jsxs(Box, {
                component: "nav",
                ...containerProps,
                children: [
                    currentPosition === 'top' && lastChild,
                    /*#__PURE__*/ jsx(Breadcrumbs$1, {
                        component: "div",
                        ref: ref,
                        ...props,
                        children: previousChildren
                    }),
                    currentPosition === 'bottom' && lastChild
                ]
            })
        });
    }
    return /*#__PURE__*/ jsx(Breadcrumbs$1, {
        ref: ref,
        ...props,
        children: children
    });
});

export { Breadcrumbs as B };
