'use client';
import { jsxs, jsx } from 'react/jsx-runtime';
import MuiButton from '@mui/material/Button';
import CircularProgress from '@mui/material/CircularProgress';
import { forwardRef } from 'react';

/**
 * 合併 SxProps 物件陣列，並過濾掉 false 和 undefined 的值。
 *
 * @param styles 要合併的 SxProps 物件陣列
 */ const mergeSx = (...styles)=>styles.reduce((acc, sx)=>{
        if (!sx) return acc;
        if (Array.isArray(sx)) {
            return [
                ...acc,
                ...sx
            ];
        }
        return [
            ...acc,
            sx
        ];
    }, []);

/**
 * 表示一個可點擊的按鈕元件，用於觸發相關的業務邏輯。
 *
 * 參考 [Material-UI Button](https://mui.com/material-ui/react-button/)
 *
 * @example
 *
 *  ```tsx
 * <Button variant="contained">Contained</Button>
 * <Button variant="outlined">Outlined</Button>
 * <Button variant="text">Text</Button>
 * ```
 */ const Button = /*#__PURE__*/ forwardRef((props, ref)=>{
    const { children, sx, loading = false, disabled = false, shape = 'default', variant = 'contained', ...rest } = props;
    return /*#__PURE__*/ jsxs(MuiButton, {
        ref: ref,
        sx: mergeSx({
            '&.MuiButton-text:hover': {
                backgroundColor: 'inherit'
            },
            '&.Mui-disabled': {
                pointerEvents: 'inherit',
                cursor: 'not-allowed'
            }
        }, shape === 'round' && {
            borderRadius: '40px',
            paddingInlineStart: '20px',
            paddingInlineEnd: '20px'
        }, sx),
        variant: variant,
        disabled: loading || disabled,
        ...rest,
        children: [
            children,
            loading && /*#__PURE__*/ jsx(CircularProgress, {
                sx: {
                    ml: 1
                },
                color: "inherit",
                size: "1.5em"
            })
        ]
    });
});

export { Button as B, mergeSx as m };
