'use client';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import '@mui/material/Button';
import '@mui/material/CircularProgress';
import { forwardRef, useState } from 'react';
import '@mui/material/IconButton';
import { Close } from '@mui/icons-material';
import { Drawer as Drawer$1, Box } from '@mui/material';
import { m as mergeSx, B as Button } from './Button-12s-G2UrgcxM.mjs';
import { I as IconButton } from './IconButton-12s-D7ClqGFi.mjs';
import { D as DecorativeTitle } from './DecorativeTitle-12s-ry4VkkkC.mjs';
import { L as LoadingContent } from './Card-12s-DPGP1C0M.mjs';
import '@mui/material/Backdrop';

/**
 * `Drawer` 抽屜元件，由螢幕邊緣滑出的浮動面版，
 * 常見的應用是作為導航用途，例如 Navigation drawers。
 *
 * 參考 [Material-UI Button](https://mui.com/material-ui/react-drawer/)
 */ const Drawer = /*#__PURE__*/ forwardRef(({ title, loading = false, loadingOptions, showCloseIcon = true, headerProps = {}, disableBackdropClick = false, contentProps = {}, actionsProps = {}, onClose: onCloseOuter, onSubmit, submitText = 'Submit', cancelText = 'Cancel', customActions, anchor = 'right', children, ...rest }, ref)=>{
    const [isSubmitting, setIsSubmitting] = useState(false);
    const handleCloseInter = (event, reason)=>{
        if (reason === 'backdropClick' && disableBackdropClick || isSubmitting) {
            return;
        }
        onCloseOuter?.(event, reason);
    };
    const handleCloseButtonClick = (event)=>{
        if (!isSubmitting) {
            onCloseOuter?.(event, 'closeButtonClick');
        }
    };
    const handleSubmit = async ()=>{
        setIsSubmitting(true);
        try {
            await onSubmit?.();
        } finally{
            setIsSubmitting(false);
        }
    };
    return /*#__PURE__*/ jsxs(Drawer$1, {
        ref: ref,
        ...rest,
        anchor: anchor,
        onClose: handleCloseInter,
        PaperProps: {
            ...rest?.PaperProps,
            sx: mergeSx({
                minWidth: {
                    xs: '100%',
                    md: '30%'
                }
            }, rest?.PaperProps?.sx)
        },
        children: [
            (title || showCloseIcon) && /*#__PURE__*/ jsxs(Box, {
                ...headerProps,
                sx: mergeSx({
                    px: 3,
                    py: 2,
                    display: 'flex',
                    alignItems: 'center',
                    justifyContent: 'space-between'
                }, headerProps?.sx),
                children: [
                    /*#__PURE__*/ jsx(DecorativeTitle, {
                        sx: {
                            flex: 1
                        },
                        loading: loading,
                        ...headerProps?.titleProps,
                        children: title
                    }),
                    showCloseIcon && /*#__PURE__*/ jsx(IconButton, {
                        "aria-label": "drawer-close",
                        onClick: handleCloseButtonClick,
                        disabled: isSubmitting,
                        sx: {
                            color: 'text.secondary'
                        },
                        size: "small",
                        children: /*#__PURE__*/ jsx(Close, {})
                    })
                ]
            }),
            /*#__PURE__*/ jsx(Box, {
                ...contentProps,
                sx: mergeSx({
                    px: 3,
                    py: 2,
                    overflow: 'auto',
                    flexGrow: 1
                }, (contentProps?.dividers ?? true) && {
                    borderTop: 1,
                    borderBottom: 1,
                    borderColor: 'divider'
                }, contentProps?.sx),
                children: loading ? /*#__PURE__*/ jsx(LoadingContent, {
                    ...loadingOptions
                }) : children
            }),
            (onSubmit || customActions) && /*#__PURE__*/ jsx(Box, {
                ...actionsProps,
                sx: mergeSx({
                    p: 1.5,
                    position: 'sticky',
                    bottom: 0,
                    display: 'flex',
                    alignItems: 'center',
                    justifyContent: 'center',
                    gap: 1.5
                }, actionsProps?.sx),
                children: customActions || /*#__PURE__*/ jsxs(Fragment, {
                    children: [
                        /*#__PURE__*/ jsx(Button, {
                            variant: "outlined",
                            size: "medium",
                            onClick: handleCloseButtonClick,
                            disabled: isSubmitting,
                            children: cancelText
                        }),
                        /*#__PURE__*/ jsx(Button, {
                            variant: "contained",
                            size: "medium",
                            onClick: handleSubmit,
                            loading: isSubmitting,
                            children: submitText
                        })
                    ]
                })
            })
        ]
    });
});
if (process.env.NODE_ENV !== 'production') {
    Drawer.displayName = 'GwDrawer';
}

export { Drawer as D };
