'use client';
import { jsx } from 'react/jsx-runtime';
import { useTheme, useMediaQuery } from '@mui/material';
import Box from '@mui/material/Box';
import { forwardRef, useState, useCallback, useMemo, createContext, useContext } from 'react';

const SIDEBAR_WIDTH = 260;
const SIDEBAR_WIDTH_MOBILE = 300;
const SIDEBAR_WIDTH_ICON = 50;
const SidebarContext = /*#__PURE__*/ createContext(null);
const useSidebar = ()=>{
    const context = useContext(SidebarContext);
    if (!context) {
        throw new Error('useSidebar must be used within a SidebarProvider.');
    }
    return context;
};
const SidebarProvider = /*#__PURE__*/ forwardRef(({ widthConfig: widthConfigProps, defaultOpen = true, open: outerOpen, onOpenChange: setOuterOpen, children, sx, ...props }, ref)=>{
    const theme = useTheme();
    const isMobile = useMediaQuery(theme.breakpoints.between('xs', 'sm'));
    const [openMobile, setOpenMobile] = useState(false);
    // This is the internal state of the sidebar.
    // We use outerOpen and setOuterOpen for control from outside the component.
    const [innerOpen, setInnerOpen] = useState(defaultOpen);
    const open = outerOpen ?? innerOpen;
    const setOpen = useCallback((value)=>{
        const openState = typeof value === 'function' ? value(open) : value;
        if (setOuterOpen) {
            setOuterOpen(openState);
        } else {
            setInnerOpen(openState);
        }
    }, [
        setOuterOpen,
        open
    ]);
    // Helper to toggle the sidebar.
    const toggleSidebar = useCallback(()=>isMobile ? setOpenMobile((preOpen)=>!preOpen) : setOpen((preOpen)=>!preOpen), [
        isMobile,
        setOpen,
        setOpenMobile
    ]);
    const width = useMemo(()=>{
        const widthConfig = {
            ...{
                width: SIDEBAR_WIDTH,
                widthIcon: SIDEBAR_WIDTH_ICON,
                widthMobile: SIDEBAR_WIDTH_MOBILE
            },
            ...widthConfigProps
        };
        if (isMobile) return widthConfig.widthMobile;
        return open ? widthConfig.width : widthConfig.widthIcon;
    }, [
        isMobile,
        open,
        widthConfigProps
    ]);
    const contextValue = useMemo(()=>({
            open,
            setOpen,
            isMobile,
            openMobile,
            setOpenMobile,
            toggleSidebar,
            width
        }), [
        open,
        setOpen,
        isMobile,
        openMobile,
        setOpenMobile,
        toggleSidebar,
        width
    ]);
    return /*#__PURE__*/ jsx(SidebarContext.Provider, {
        value: contextValue,
        children: /*#__PURE__*/ jsx(Box, {
            ref: ref,
            sx: {
                display: 'flex',
                minHeight: '100svh',
                ...sx
            },
            ...props,
            children: children
        })
    });
});
SidebarProvider.displayName = 'SidebarProvider';

export { SidebarProvider as S, useSidebar as u };
