'use client';
import { jsx } from 'react/jsx-runtime';
import { VisibilityOff, Visibility, Clear } from '@mui/icons-material';
import { InputAdornment, IconButton, Box, TextField as TextField$1, mergeSlotProps } from '@mui/material';
import { forwardRef, useState, useMemo } from 'react';

const TextFieldInner = ({ value, onChange, defaultValue, type, allowShowPassword = false, allowClear, selectPlaceholder = 'please select', ...props }, ref)=>{
    const [showPassword, setShowPassword] = useState(false);
    const passwordProps = useMemo(()=>{
        if (type !== 'password' || !allowShowPassword) return {};
        return {
            type: showPassword ? 'text' : 'password',
            endAdornment: /*#__PURE__*/ jsx(InputAdornment, {
                position: "end",
                children: /*#__PURE__*/ jsx(IconButton, {
                    onClick: ()=>setShowPassword((show)=>!show),
                    onMouseDown: (event)=>{
                        event.preventDefault();
                    },
                    "aria-label": "toggle password visibility",
                    children: showPassword ? /*#__PURE__*/ jsx(VisibilityOff, {}) : /*#__PURE__*/ jsx(Visibility, {})
                })
            })
        };
    }, [
        type,
        allowShowPassword,
        showPassword
    ]);
    const selectProps = useMemo(()=>{
        if (!props.select) return {};
        const finalValue = value ?? defaultValue;
        return {
            displayEmpty: true,
            renderValue: finalValue || finalValue === 0 ? undefined : ()=>/*#__PURE__*/ jsx(Box, {
                    component: "span",
                    color: "text.disabled",
                    children: selectPlaceholder
                }),
            ...allowClear && {
                endAdornment: /*#__PURE__*/ jsx(IconButton, {
                    className: "MuiClear-icon",
                    onClick: ()=>{
                        onChange?.({
                            target: {
                                value: ''
                            }
                        });
                    },
                    onMouseDown: (event)=>{
                        event.preventDefault();
                    },
                    "aria-label": "clear",
                    sx: {
                        display: 'none',
                        width: '1em',
                        height: '1em',
                        position: 'absolute',
                        right: '7px',
                        top: 'calc(50% - .5em)'
                    },
                    children: /*#__PURE__*/ jsx(Clear, {
                        color: "action",
                        fontSize: "small"
                    })
                })
            }
        };
    }, [
        value,
        defaultValue,
        props.select,
        selectPlaceholder,
        allowClear,
        onChange
    ]);
    return /*#__PURE__*/ jsx(TextField$1, {
        ...props,
        ref: ref,
        type: type,
        value: value,
        onChange: onChange,
        defaultValue: defaultValue,
        slotProps: {
            input: mergeSlotProps(props.slotProps?.input, {
                ...passwordProps,
                sx: {
                    '&:hover :is(fieldset)': {
                        borderColor: (theme)=>`${theme.palette.primary.dark} !important`
                    },
                    '& input[type=number]': {
                        MozAppearance: 'textfield'
                    },
                    '& input::-webkit-outer-spin-button, & input::-webkit-inner-spin-button': {
                        WebkitAppearance: 'none',
                        m: 0
                    }
                }
            }),
            inputLabel: mergeSlotProps(props.slotProps?.inputLabel, {
                shrink: true,
                sx: {
                    '.MuiFormLabel-asterisk': {
                        color: 'error.main'
                    }
                }
            }),
            select: mergeSlotProps(props.slotProps?.select, {
                ...selectProps,
                sx: {
                    '&:hover': {
                        '.MuiSelect-icon': {
                            display: 'none'
                        },
                        '.MuiClear-icon': {
                            display: 'inline-flex'
                        }
                    }
                }
            })
        }
    });
};
/**
 * `TextField` 元件代表一個文字輸入框，也可以用於選擇框，用於須將label呈現在輸入框border上的情況。
 *
 * 參考 [Material-UI Text Field](https://mui.com/material-ui/react-text-field/)
 */ const TextField = /*#__PURE__*/ forwardRef(TextFieldInner);

export { TextField as T };
