'use client';
import { jsxs, jsx } from 'react/jsx-runtime';
import { validateFileType } from '@gateweb/react-utils';
import { Stack } from '@mui/material';
import { F as FileList } from './FileList-12s-BJbpuk72.mjs';
import { U as UploadButton } from './UploadButton-12s-CMJxBIvR.mjs';
import { U as UploadPanel } from './UploadPanel-12s-BGRemsP0.mjs';
import { u as useFileUpload } from './useFileUpload-12s-CCDiOt__.mjs';

const UploadFile = (props)=>{
    const { acceptMimeTypes = [], maxFiles = 1, files: outerFiles, onAddFile, onRemoveFile, onTypeError, i18n, type = 'drag-and-drop', ...rest } = props;
    const { files, addFile, removeFile } = useFileUpload({
        files: outerFiles,
        onAddFile,
        onRemoveFile
    });
    const handleAddFile = (e)=>{
        if (!e.target.files || e.target.files.length === 0) return;
        const targetFile = e.target.files[0];
        if (!validateFileType(targetFile, acceptMimeTypes)) {
            onTypeError?.();
            return;
        }
        addFile(targetFile);
    };
    const handleDropFile = (e)=>{
        if (!e.dataTransfer.files) return;
        const targetFile = e.dataTransfer.files[0];
        if (!validateFileType(targetFile, acceptMimeTypes)) {
            onTypeError?.();
            return;
        }
        addFile(targetFile);
    };
    if (type === 'drag-and-drop') {
        return /*#__PURE__*/ jsxs(Stack, {
            spacing: 2,
            ...rest,
            children: [
                /*#__PURE__*/ jsx(UploadPanel, {
                    acceptMimeTypes: acceptMimeTypes,
                    handleAddFile: handleAddFile,
                    handleDropFile: handleDropFile,
                    disabled: maxFiles <= files.length,
                    i18n: i18n
                }),
                /*#__PURE__*/ jsx(FileList, {
                    files: files,
                    handleDeleteFile: removeFile
                })
            ]
        });
    }
    return /*#__PURE__*/ jsxs(Stack, {
        spacing: 2,
        ...rest,
        children: [
            /*#__PURE__*/ jsx(FileList, {
                files: files,
                handleDeleteFile: removeFile
            }),
            maxFiles > files.length && /*#__PURE__*/ jsx(UploadButton, {
                acceptMimeTypes: acceptMimeTypes,
                handleAddFile: handleAddFile,
                type: "compact-list"
            })
        ]
    });
};

export { UploadFile as U };
