'use client';
import { jsx, jsxs } from 'react/jsx-runtime';
import { Typography, FormControl, Stack, FormLabel, Tooltip, Box, FormHelperText } from '@mui/material';
import { forwardRef } from 'react';
import { u as useBreadcrumbs } from './BreadCrumbContext-12s-DPRdxc6-.mjs';
import '@mui/material/Skeleton';
import '@mui/material/Typography';
import '@mui/material/Backdrop';
import '@mui/material/CircularProgress';
import './Card-12s-DPGP1C0M.mjs';
import '@mui/icons-material/ExpandMore';
import './Drawer-12s-DQy0xT4K.mjs';
import { HelpOutlineOutlined } from '@mui/icons-material';
import '@mui/material/Stack';
import '@gateweb/react-utils';
import '@mui/material/Box';
import '@mui/material/Button';
import '@mui/material/IconButton';
import './Modal-12s-DTPK_oxV.mjs';
import './Sidebar-12s-55RVBTYw.mjs';
import './SidebarContext-12s-BVJtalEE.mjs';
import './Switch-12s-p2lNmHws.mjs';
import './Table-12s-BUdm4QDz.mjs';
import 'react-number-format';
import './OTPField-12s-DJAHG9jr.mjs';
import '@mui/material/Alert';
import '@mui/material/Snackbar';
import './UploadButton-12s-CMJxBIvR.mjs';

/**
 * `BreadcrumbItem` 是 `Breadcrumb` 的子元件，用於顯示當前路徑的每一個節點。
 *
 * @example
 *
 * ```tsx
 * <Breadcrumbs>
 *  <BreadcrumbItem>Home</BreadcrumbItem>
 *  <BreadcrumbItem>Components</BreadcrumbItem>
 *  <BreadcrumbItem isLast>Button</BreadcrumbItem>
 * </Breadcrumbs>
 * ```
 */ const BreadcrumbItem = /*#__PURE__*/ forwardRef(({ isLast, ...rest }, ref)=>{
    const context = useBreadcrumbs();
    if (isLast && context?.extractCurrent) {
        return /*#__PURE__*/ jsx(Typography, {
            ref: ref,
            variant: "h4",
            fontWeight: "bold",
            color: "text.primary",
            ...rest
        });
    }
    return /*#__PURE__*/ jsx(Typography, {
        ref: ref,
        variant: "subtitle1",
        fontWeight: isLast ? 'bold' : 'normal',
        color: isLast ? 'text.primary' : 'text.secondary',
        ...rest
    });
});

/**
 * `FormItem` 讓我們可以將 form input 所需要的共同前後文特性獨立出來管理，
 * 使被 control 的子元件之間的樣式能夠保持一致性。
 * 例如在 form input 元件 `TextField`, `Switch`, `Checkbox` 當中，
 * 將 `label`, `required`, `error` ...等邏輯與樣式獨立出來藉由 FormItem 來管理。
 *
 * 參考 [Material-UI: FormControl](https://mui.com/material-ui/api/form-control/)
 */ const FormItem = ({ children, label, helperText, helpInfo, maxLength, currentLength, error, fullWidth = true, ...rest })=>/*#__PURE__*/ jsxs(FormControl, {
        fullWidth: fullWidth,
        error: error,
        ...rest,
        children: [
            /*#__PURE__*/ jsxs(Stack, {
                direction: "row",
                justifyContent: "space-between",
                children: [
                    /*#__PURE__*/ jsxs(Stack, {
                        direction: "row",
                        alignItems: "center",
                        justifyContent: "center",
                        spacing: 0.5,
                        sx: {
                            position: 'relative',
                            width: 'fit-content'
                        },
                        children: [
                            /*#__PURE__*/ jsx(FormLabel, {
                                sx: {
                                    fontSize: '0.8rem',
                                    py: 0.5,
                                    '& .MuiFormLabel-asterisk': {
                                        color: 'error.main'
                                    }
                                },
                                children: label
                            }),
                            helpInfo && /*#__PURE__*/ jsx(Tooltip, {
                                title: helpInfo,
                                placement: "top",
                                enterTouchDelay: 50,
                                children: /*#__PURE__*/ jsx(HelpOutlineOutlined, {
                                    color: "info",
                                    fontSize: "small"
                                })
                            })
                        ]
                    }),
                    maxLength !== undefined && /*#__PURE__*/ jsx(Typography, {
                        component: "span",
                        sx: {
                            fontSize: '0.8rem'
                        },
                        color: error ? 'error' : 'text.secondary',
                        children: `${currentLength ?? 0}/${maxLength}`
                    })
                ]
            }),
            /*#__PURE__*/ jsx(Box, {
                sx: {
                    minHeight: 40,
                    display: 'flex',
                    alignItems: 'flex-start'
                },
                children: children
            }),
            helperText && /*#__PURE__*/ jsx(FormHelperText, {
                children: helperText
            })
        ]
    });

export { BreadcrumbItem as B, FormItem as F };
